@@ -1,4 +1,4 @@
-/* $Id: util.c,v 1.1 2001/07/27 14:37:08 hpa Exp $ */
+/* $Id: util.c,v 1.2 2001/07/31 03:20:52 hpa Exp $ */
 /* ----------------------------------------------------------------------- *
  *   
  *   Copyright 2001 H. Peter Anvin - All Rights Reserved
@@ -48,7 +48,7 @@ void message(enum verbosity level, const char *format, ...)
   va_list ap;
 
   va_start(ap, format);
-  if ( verbosity >= level )
+  if ( opt.verbosity >= level )
     vfprintf(stderr, format, ap);
   va_end(ap);
 }
